<?php
/**
 * Plugin Name: Simple Chat Bot
 * Description: A Simple Chat Bot with WhatsApp redirect.
 * Version: 1.0
 * Author: Sachinraj CP
 * Text Domain: simple-chat-bot
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

// Add settings menu
add_action('admin_menu', 'simple_chatbot_menu');
function simple_chatbot_menu() {
    add_menu_page('Simple Chatbot Settings', 'Chatbot Settings', 'manage_options', 'simple-chatbot-settings', 'simple_chatbot_settings_page');
}

function simple_chatbot_settings_page() {
    ?>
    <div class="wrap">
        <h1>Simple Chatbot Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('simple_chatbot_options_group');
            do_settings_sections('simple_chatbot_options_group');
            $whatsapp_number = get_option('simple_chatbot_whatsapp_number', '');
            ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">WhatsApp Number</th>
                    <td>
                        <input type="text" name="simple_chatbot_whatsapp_number" value="<?php echo esc_attr($whatsapp_number); ?>" style="width: 100%;" placeholder="1234567890" />
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

add_action('admin_init', 'simple_chatbot_register_settings');
function simple_chatbot_register_settings() {
    register_setting('simple_chatbot_options_group', 'simple_chatbot_whatsapp_number', 'sanitize_text_field');
}

// Enqueue assets
function simple_chatbot_enqueue_assets() {
    wp_enqueue_style('chatbot-css', plugin_dir_url(__FILE__) . 'css/chatbot.css', array(), '1.0');
    wp_enqueue_script('chatbot-js', plugin_dir_url(__FILE__) . 'js/chatbot.js', array('jquery'), '1.0', true);
    $whatsapp_number = get_option('simple_chatbot_whatsapp_number', '');
    $whatsapp_link = $whatsapp_number ? "https://wa.me/" . esc_attr($whatsapp_number) : '';
    wp_localize_script('chatbot-js', 'simpleChatbotData', array('whatsapp_link' => $whatsapp_link));
}
add_action('wp_enqueue_scripts', 'simple_chatbot_enqueue_assets');

// Output HTML
add_action('wp_footer', 'simple_chatbot');
function simple_chatbot() {
    ?>
<div id="chatbot-container" style="display: none;">
    <div id="chatbot-header">
        <span>Chatbot</span>
        <button id="end-chat" class="end-chat-button">&times;</button>
    </div>
    <div id="chatbot-messages"></div>
    <div style="display: flex; padding: 10px;">
        <input type="text" id="chatbot-input" placeholder="Type your message..." />
        <button id="chatbot-send">Send</button>
    </div>
</div>
<button id="start-chat">
    <i class="fas fa-comments"></i>
    <span>Simple Chat Bot</span> <!-- Sliding text only appears on hover -->
</button>


    <?php
}
